@@ -36,6 +36,7 @@ class MobileCommand(object):
     KEY_EVENT = 'keyEvent' # Needed for Selendroid
     LONG_PRESS_KEYCODE = 'longPressKeyCode'
     GET_CURRENT_ACTIVITY = 'getCurrentActivity'
+    GET_CURRENT_PACKAGE = 'getCurrentPackage'
     SET_IMMEDIATE_VALUE = 'setImmediateValue'
     PULL_FILE = 'pullFile'
     PULL_FOLDER = 'pullFolder'
@@ -50,6 +51,7 @@ class MobileCommand(object):
     LOCK = 'lock'
     SHAKE = 'shake'
     TOUCH_ID = 'touchId'
+    TOGGLE_TOUCH_ID_ENROLLMENT = 'toggleTouchIdEnrollment'
     RESET = 'reset'
     HIDE_KEYBOARD = 'hideKeyboard'
     REPLACE_KEYS = 'replaceKeys'
@@ -58,3 +60,4 @@ class MobileCommand(object):
     UPDATE_SETTINGS = 'updateSettings'
     SET_LOCATION = 'setLocation'
     GET_DEVICE_TIME = 'getDeviceTime'
+    CLEAR = 'clear'
